@@ -236,7 +236,7 @@ void set_platform_ui(void)
 #else
 	   FL_NORMAL_SIZE = 12;
 #endif
-
+/*
 float dpx, dpy;
     Fl::screen_dpi ( dpx, dpy );
 
@@ -246,6 +246,7 @@ float scrn_scale = dpx / 90.0;
 
 // std::cout << "new screen scale factor: " << scrn_scale << std::endl;
     Fl::screen_scale(0, scrn_scale);
+*/
 }
 #endif
 
@@ -275,10 +276,11 @@ Pixmap  Rig_icon_pixmap;
 
 void make_pixmap(Pixmap *xpm, const char **data)
 {
-	Fl_Window w(0,0, KNAME);
-	w.xclass(KNAME);
-	w.show();
-	w.make_current();
+	Fl_Window *w = new Fl_Window(10, 10, KNAME);
+	w->xclass(KNAME);
+	w->show();
+	w->make_current();
+
 	Fl_Pixmap icon(data);
 	int maxd = (icon.w() > icon.h()) ? icon.w() : icon.h();
 	*xpm = fl_create_offscreen(maxd, maxd);
@@ -287,6 +289,8 @@ void make_pixmap(Pixmap *xpm, const char **data)
 	fl_rectf(0, 0, maxd, maxd);
 	icon.draw(maxd - icon.w(), maxd - icon.h());
 	fl_end_offscreen();
+
+	delete w;
 }
 
 #endif
@@ -376,6 +380,7 @@ void startup(void*)
 		}
 		case small_ui :
 		default :
+			mainwindow->resize(progStatus.mainX, progStatus.mainY, progStatus.mainW, progStatus.mainH);
 			break;
 	}
 	start_server(xmlport);
@@ -477,7 +482,7 @@ int main (int argc, char *argv[])
 	SepSerial	= new Cserial;
 	AuxSerial	= new Cserial;
 	cwio_serial	= new Cserial();
-	morse		= new Cmorse();
+	morse		= new cMorse();
 	FSK_serial	= new Cserial();
 
 	try {
@@ -529,6 +534,11 @@ int main (int argc, char *argv[])
 	}
 	mainwindow->callback(exit_main);
 
+#if FLRIG_FLTK_API_MINOR >3
+	mainwindow->screen_num(progStatus.screen_number);
+	Fl::screen_scale(progStatus.screen_number, progStatus.screen_scale / 100.0);
+#endif
+
 	meters_dialog = win_meters();
 
 //	progStatus.UI_laststate();
@@ -716,7 +726,6 @@ int parse_args(int argc, char **argv, int& idx)
   --xml-trace\n\
   --exp (expand menu tab controls)\n\
   --iconify {-i}\n\
-  --priority {-p}\n\
   --test\n";
 
 	if (strcasecmp("--help", argv[idx]) == 0) {
@@ -769,11 +778,6 @@ int parse_args(int argc, char **argv, int& idx)
 		idx++;
 		return 1;
 	}
-	if (!strcasecmp(argv[idx], "-p") || !strcasecmp(argv[idx], "--priority")) {
-		PRIORITY = true;
-		idx++;
-		return 1;
-	}
 
 	if (strcasecmp("--debug-level", argv[idx]) == 0) {
 		std::string level = argv[idx + 1];
